summaryrefslogtreecommitdiff
path: root/src/tools
diff options
context:
space:
mode:
authorHeejin Ahn <aheejin@gmail.com>2021-06-18 14:20:03 -0700
committerGitHub <noreply@github.com>2021-06-18 14:20:03 -0700
commit28e88b9f993a2e45662fde0b10920aa22e7b1b7f (patch)
tree77bbd5f1dd1bfcb089b12f6fa9fcf828c135c099 /src/tools
parent97e277c51218778d1d76fd59fed3b4ca7756382e (diff)
downloadbinaryen-28e88b9f993a2e45662fde0b10920aa22e7b1b7f.tar.gz
binaryen-28e88b9f993a2e45662fde0b10920aa22e7b1b7f.tar.bz2
binaryen-28e88b9f993a2e45662fde0b10920aa22e7b1b7f.zip
[EH] Replace event with tag (#3937)
We recently decided to change 'event' to 'tag', and to 'event section' to 'tag section', out of the rationale that the section contains a generalized tag that references a type, which may be used for something other than exceptions, and the name 'event' can be confusing in the web context. See - https://github.com/WebAssembly/exception-handling/issues/159#issuecomment-857910130 - https://github.com/WebAssembly/exception-handling/pull/161
Diffstat (limited to 'src/tools')
-rw-r--r--src/tools/fuzzing.h13
-rw-r--r--src/tools/wasm-metadce.cpp35
2 files changed, 23 insertions, 25 deletions
diff --git a/src/tools/fuzzing.h b/src/tools/fuzzing.h
index 0635dc61d..f1fc61e06 100644
--- a/src/tools/fuzzing.h
+++ b/src/tools/fuzzing.h
@@ -200,7 +200,7 @@ public:
setupTables();
setupGlobals();
if (wasm.features.hasExceptionHandling()) {
- setupEvents();
+ setupTags();
}
modifyInitialFunctions();
addImportLoggingSupport();
@@ -495,14 +495,13 @@ private:
}
}
- void setupEvents() {
+ void setupTags() {
Index num = upTo(3);
for (size_t i = 0; i < num; i++) {
- auto event =
- builder.makeEvent(Names::getValidEventName(wasm, "event$"),
- WASM_EVENT_ATTRIBUTE_EXCEPTION,
- Signature(getControlFlowType(), Type::none));
- wasm.addEvent(std::move(event));
+ auto tag = builder.makeTag(Names::getValidTagName(wasm, "tag$"),
+ WASM_TAG_ATTRIBUTE_EXCEPTION,
+ Signature(getControlFlowType(), Type::none));
+ wasm.addTag(std::move(tag));
}
}
diff --git a/src/tools/wasm-metadce.cpp b/src/tools/wasm-metadce.cpp
index a0890c8c4..29ac01f90 100644
--- a/src/tools/wasm-metadce.cpp
+++ b/src/tools/wasm-metadce.cpp
@@ -58,12 +58,12 @@ struct MetaDCEGraph {
std::unordered_map<Name, Name> exportToDCENode;
std::unordered_map<Name, Name> functionToDCENode; // function name => DCE name
std::unordered_map<Name, Name> globalToDCENode; // global name => DCE name
- std::unordered_map<Name, Name> eventToDCENode; // event name => DCE name
+ std::unordered_map<Name, Name> tagToDCENode; // tag name => DCE name
std::unordered_map<Name, Name> DCENodeToExport; // reverse maps
std::unordered_map<Name, Name> DCENodeToFunction;
std::unordered_map<Name, Name> DCENodeToGlobal;
- std::unordered_map<Name, Name> DCENodeToEvent;
+ std::unordered_map<Name, Name> DCENodeToTag;
// imports are not mapped 1:1 to DCE nodes in the wasm, since env.X might
// be imported twice, for example. So we don't map a DCE node to an Import,
@@ -95,8 +95,8 @@ struct MetaDCEGraph {
return getImportId(imp->module, imp->base);
}
- ImportId getEventImportId(Name name) {
- auto* imp = wasm.getEvent(name);
+ ImportId getTagImportId(Name name) {
+ auto* imp = wasm.getTag(name);
return getImportId(imp->module, imp->base);
}
@@ -126,14 +126,14 @@ struct MetaDCEGraph {
globalToDCENode[global->name] = dceName;
nodes[dceName] = DCENode(dceName);
});
- ModuleUtils::iterDefinedEvents(wasm, [&](Event* event) {
- auto dceName = getName("event", event->name.str);
- DCENodeToEvent[dceName] = event->name;
- eventToDCENode[event->name] = dceName;
+ ModuleUtils::iterDefinedTags(wasm, [&](Tag* tag) {
+ auto dceName = getName("tag", tag->name.str);
+ DCENodeToTag[dceName] = tag->name;
+ tagToDCENode[tag->name] = dceName;
nodes[dceName] = DCENode(dceName);
});
// only process function, global, and event imports - the table and memory
// are always there
ModuleUtils::iterImportedFunctions(wasm, [&](Function* import) {
auto id = getImportId(import->module, import->base);
if (importIdToDCENode.find(id) == importIdToDCENode.end()) {
@@ -148,7 +148,7 @@ struct MetaDCEGraph {
importIdToDCENode[id] = dceName;
}
});
- ModuleUtils::iterImportedEvents(wasm, [&](Event* import) {
+ ModuleUtils::iterImportedTags(wasm, [&](Tag* import) {
auto id = getImportId(import->module, import->base);
if (importIdToDCENode.find(id) == importIdToDCENode.end()) {
auto dceName = getName("importId", import->name.str);
@@ -178,12 +178,11 @@ struct MetaDCEGraph {
node.reaches.push_back(
importIdToDCENode[getGlobalImportId(exp->value)]);
}
- } else if (exp->kind == ExternalKind::Event) {
- if (!wasm.getEvent(exp->value)->imported()) {
- node.reaches.push_back(eventToDCENode[exp->value]);
+ } else if (exp->kind == ExternalKind::Tag) {
+ if (!wasm.getTag(exp->value)->imported()) {
+ node.reaches.push_back(tagToDCENode[exp->value]);
} else {
- node.reaches.push_back(
- importIdToDCENode[getEventImportId(exp->value)]);
+ node.reaches.push_back(importIdToDCENode[getTagImportId(exp->value)]);
}
}
}
@@ -394,8 +393,8 @@ public:
if (DCENodeToGlobal.find(name) != DCENodeToGlobal.end()) {
std::cout << " is global " << DCENodeToGlobal[name] << '\n';
}
- if (DCENodeToEvent.find(name) != DCENodeToEvent.end()) {
- std::cout << " is event " << DCENodeToEvent[name] << '\n';
+ if (DCENodeToTag.find(name) != DCENodeToTag.end()) {
+ std::cout << " is tag " << DCENodeToTag[name] << '\n';
}
for (auto target : node.reaches) {
std::cout << " reaches: " << target.str << '\n';
@@ -126,14 +126,14 @@ struct MetaDCEGraph {
nodes[dceName] = DCENode(dceName);
});
- // only process function, global, and event imports - the table and memory
- // are always there
+ // only process function, global, and tag imports - the table and memory are
+ // always there
ModuleUtils::iterImportedFunctions(wasm, [&](Function* import) {
auto id = getImportId(import->module, import->base);